/*********************************************************************************************************************
 Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.

 Licensed under the Apache License, Version 2.0 (the "License").
 You may not use this file except in compliance with the License.
 You may obtain a copy of the License at

 http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
 ******************************************************************************************************************** */
import { IdentityPool, IdentityPoolProps } from "@aws-cdk/aws-cognito-identitypool-alpha";
import { UserPool, UserPoolClient } from "aws-cdk-lib/aws-cognito";
import { Construct } from "constructs";
/**
 * Properties which configures the Identity Pool.
 */
export interface UserIdentityProps {
    /**
     * User provided Cognito UserPool.
     *
     * @default - a userpool will be created.
     */
    readonly userPool?: UserPool;
    /**
     * Configuration for the Identity Pool.
     */
    readonly identityPoolOptions?: IdentityPoolProps;
}
/**
 * Creates an Identity Pool with sane defaults configured.
 */
export declare class UserIdentity extends Construct {
    readonly userPool?: UserPool;
    readonly userPoolClient?: UserPoolClient;
    readonly identityPool: IdentityPool;
    constructor(scope: Construct, id: string, props?: UserIdentityProps);
}
//# sourceMappingURL=user-identity.d.ts.map